@@ -8,15 +8,12 @@ from .concordancerBase import ConcordancerBase, ConcordLine
 from .subCharQuery import find_compo, load_lexicon, char_match_compo, get_radicals
 from .UtilsConcord import queryMatchToken
 from .UtilsSubchar import all_plain_cql, has_cql_match_type, is_subchar
-from .UtilsStats import MI, Xsq, Gsq, Dice, DeltaP12, DeltaP21, RawCount, additive_smooth
+from .UtilsStats import additive_smooth
 
 
 class Concordancer(ConcordancerBase):
     
     lexicon = None
-    association_measures = [
-        MI, Xsq, Gsq, Dice, DeltaP21, DeltaP12, RawCount
-    ]
 
     def cql_search(self, cql: str, left=5, right=5):
         queries = cqls.parse(cql, default_attr=self._cql_default_attr, \
@@ -88,16 +85,7 @@ class Concordancer(ConcordancerBase):
         if self.lexicon is None:
             self.lexicon = load_lexicon(self.index.keys())
         return get_radicals(self.lexicon)
-        
-    @property
-    def chr_phonetic_systems(self):
-        return {
-            'moe': {
-                'phonetic_repr': 'bpm pinyin ipa'.split(),
-                'tone': list('12345'),
-                'src': 'https://github.com/g0v/moedict-data',
-            }
-        }
+
 
     @property
     def cql_attrs(self):
@@ -105,7 +93,13 @@ class Concordancer(ConcordancerBase):
             "Default": ['char'],
             "CharComponent": ['compo', 'max_depth', 'idc', 'pos'],
             "CharRadical": ['radical'],
-            "CharPhonetic": ["phon", "tone", "sys"]
+            "CharPhonetic": {
+                "moe": ['phon', 'tone', 'tp', 'sys="moe"'],
+                "廣韻": [
+                    '攝', '聲調', '韻母', '聲母', '開合', 
+                    '等第', '反切', '拼音', 'IPA', 'sys="廣韻"'
+                ]
+            }
         }
 
 
@@ -149,8 +143,7 @@ class Concordancer(ConcordancerBase):
                 func.__name__: func(O11, O12, O21, O22, E11, E12, E21, E22)\
                     for func in self.association_measures
             }
-            if 'RawCount' in stats:
-                stats['RawCount'] = int(O11)
+            stats['RawCount'] = o11.get(w, 0)
             output.append((w, stats))
         
         return sorted(output, reverse=True, key=lambda x: x[1][sort_by])
